@@ -19,8 +19,10 @@ Usage::
     list_playback_configurations_paginator: ListPlaybackConfigurationsPaginator = client.get_paginator("list_playback_configurations")
     ```
 """
-from mypy_boto3_mediatailor.client import MediaTailorClient, MediaTailorClient as Client
+from mypy_boto3_mediatailor.client import MediaTailorClient
 from mypy_boto3_mediatailor.paginator import ListPlaybackConfigurationsPaginator
 
+Client = MediaTailorClient
+
 
 __all__ = ("Client", "ListPlaybackConfigurationsPaginator", "MediaTailorClient")
